% Complete code to analyse the the properties of an electron beam from a
% SIMION calculation, with bits lifted from Beam_width.m and 
% Gaussian_fit.m.

%Command to ask for the name of the file to be analysed
Filename = input('File to be analysed: ','s');
[Status, Sheets] = xlsfinfo(Filename);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Setting up tables to collect and store data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Matrix that will hold all of the pulse durations found by gaussian fit
Duration = zeros(11,2);
Duration(1,1)=00;
Duration(2,1)=10;
Duration(3,1)=20;
Duration(4,1)=30;
Duration(5,1)=40;
Duration(6,1)=90;
Duration(7,1)=130;
Duration(8,1)=190;
Duration(9,1)=290;
Duration(10,1)=390;
Duration(11,1)=490;

% Matrix that will hold all of the Beam width determined by looking at
% the max radius of the eletron beam
Width = zeros(11,2);
Width(1,1)=00;
Width(2,1)=10;
Width(3,1)=20;
Width(4,1)=30;
Width(5,1)=40;
Width(6,1)=90;
Width(7,1)=130;
Width(8,1)=190;
Width(9,1)=290;
Width(10,1)=390;
Width(11,1)=490;

% Matrix that will hold all of the Beam width determined by looking at
% the root mean square (RMS) of the eletron beam radius
RMS = zeros(11,2);
RMS(1,1)=00;
RMS(2,1)=10;
RMS(3,1)=20;
RMS(4,1)=30;
RMS(5,1)=40;
RMS(6,1)=90;
RMS(7,1)=130;
RMS(8,1)=190;
RMS(9,1)=290;
RMS(10,1)=390;
RMS(11,1)=490;

% Matrix that will hold all of the Beam width determined by looking at
% the max radius of the eletron beam
Percen90 = zeros(11,2);
Percen90(1,1)=00;
Percen90(2,1)=10;
Percen90(3,1)=20;
Percen90(4,1)=30;
Percen90(5,1)=40;
Percen90(6,1)=90;
Percen90(7,1)=130;
Percen90(8,1)=190;
Percen90(9,1)=290;
Percen90(10,1)=390;
Percen90(11,1)=490;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pulse Duration Analysis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% First position (nominally 00 mm) analysis
%Command to read in raw electron data, and find how many electron are at
%each timestep for each positin throughout the chamber
Rawdata = xlsread(Filename, Sheets{1}, 'A3:A1003');
Timesteps = unique(Rawdata); %Finds unique timesteps in Rawdata
Numbers=histc(Rawdata(:),Timesteps); %Counts # e at each timestep
fitgauss = fit(Timesteps,Numbers,'gauss1'); %Figures out gaussian curve properties
Duration(1,2)=fitgauss.c1; %Insets gaussian data to output

% Second position (nominally 10 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'L3:L1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(2,2)=fitgauss.c1;

% Third position (nominally 20 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'W3:W1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(3,2)=fitgauss.c1;

% Fourth position (nominally 30 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'AH3:AH1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(4,2)=fitgauss.c1;

% Fifth position (nominally 40 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'AS3:AS1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(5,2)=fitgauss.c1;

% Sixth position (nominally 90 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'BD3:BD1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(6,2)=fitgauss.c1;

% Seventh position (nominally 130 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'BO3:BO1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(7,2)=fitgauss.c1;

% Eigth position (nominally 190 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'BZ3:BZ1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(8,2)=fitgauss.c1;

% Ninth position (nominally 290 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'CK3:CK1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(9,2)=fitgauss.c1;

% Tenth position (nominally 390 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'CV3:CV1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(10,2)=fitgauss.c1;

% Eleventh position (nominally 490 mm) analysis
Rawdata = xlsread(Filename, Sheets{1}, 'DG3:DG1003');
Timesteps = unique(Rawdata); 
Numbers=histc(Rawdata(:),Timesteps); 
fitgauss = fit(Timesteps,Numbers,'gauss1');
Duration(11,2)=fitgauss.c1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Beam Width Analysis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% First position (nominally 00 mm) analysis
%Command to read in raw electron data, and find how many electron are at
%each timestep for each positin throughout the chamber
Y = xlsread(Filename, Sheets{1}, 'C3:C1003'); %Y-position
Z = xlsread(Filename, Sheets{1}, 'D3:D1003'); %Z-position
datpoints = size(Y);
r=zeros((datpoints(1,1)),1); %Setting vector to record radius

% For loop to determine the radial position of each electron
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
% Finding the furthest out electron and setting Width to its radius
Width(1,2)=max(r);
Percen90(1,2)=prctile(r,90);
RMS(1,2)=rms(r);

% % Second position (nominally 10 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'N3:N1003');
Z = xlsread(Filename, Sheets{1}, 'O3:O1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(2,2)=max(r);
Percen90(2,2)=prctile(r,90);
RMS(2,2)=rms(r);

% % Third position (nominally 20 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'Y3:Y1003');
Z = xlsread(Filename, Sheets{1}, 'Z3:Z1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(3,2)=max(r);
Percen90(3,2)=prctile(r,90);
RMS(3,2)=rms(r);

% % Fourth position (nominally 30 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'AJ3:AJ1003');
Z = xlsread(Filename, Sheets{1}, 'AK3:AK1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(4,2)=max(r);
Percen90(4,2)=prctile(r,90);
RMS(4,2)=rms(r); 

% % Fifth position (nominally 40 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'AU3:AU1003');
Z = xlsread(Filename, Sheets{1}, 'AV3:AV1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(5,2)=max(r);
Percen90(5,2)=prctile(r,90);
RMS(5,2)=rms(r); 

% % Sixth position (nominally 90 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'BF3:BF1003');
Z = xlsread(Filename, Sheets{1}, 'BG3:BG1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(6,2)=max(r);
Percen90(6,2)=prctile(r,90);
RMS(6,2)=rms(r);

% % Seventh position (nominally 130 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'BQ3:BQ1003');
Z = xlsread(Filename, Sheets{1}, 'BR3:BR1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(7,2)=max(r);
Percen90(7,2)=prctile(r,90);
RMS(7,2)=rms(r);

% % Eigth position (nominally 190 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'CB3:CB1003');
Z = xlsread(Filename, Sheets{1}, 'CC3:CC1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(8,2)=max(r);
Percen90(8,2)=prctile(r,90);
RMS(8,2)=rms(r);

% % Ninth position (nominally 290 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'CM3:CM1003');
Z = xlsread(Filename, Sheets{1}, 'CN3:CN1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(9,2)=max(r);
Percen90(9,2)=prctile(r,90);
RMS(9,2)=rms(r);

% % Tenth position (nominally 390 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'CX3:CX1003');
Z = xlsread(Filename, Sheets{1}, 'CY3:CY1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(10,2)=max(r);
Percen90(10,2)=prctile(r,90);
RMS(10,2)=rms(r);

% % Eleventh position (nominally 490 mm) analysis
Y = xlsread(Filename, Sheets{1}, 'DI3:DI1003');
Z = xlsread(Filename, Sheets{1}, 'DJ3:DJ1003');
for i=1:datpoints(1,1), 
     r(i,1)=((Y(i,1))^2+(Z(i,1)^2))^(0.5);
end
Width(11,2)=max(r);
Percen90(11,2)=prctile(r,90);
RMS(11,2)=rms(r);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Compiled Results Table
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Results=zeros(11,6);
for j=1:11
    Results(j,1)=Duration(j,1);
    Results(j,2)=Duration(j,2);
    Results(j,3)=Duration(j,2)*1e9;
    Results(j,4)=Width(j,2);
    Results(j,5)=Percen90(j,2);
    Results(j,6)=RMS(j,2);
end
