% This is the basic "figuring out" code to look at three 
% atom system (water) before being upgraded to hopefully 
% deal with any molecule
% Code quickly reads information from an excel file 
% and then uses this to determine the ra atomic distance 
% between atoms from Michal Kochman's QM/MM code

%Command to ask for the name of the file to be analysed
Filename = input('File to be analysed: ','s');
[Status, Sheets] = xlsfinfo(Filename);

% Read number of atoms. This must beinserted manually 
% at the top of the excel file.
Atoms = xlsread(Filename, Sheets{1}, 'A1');

%Calculate the number of atomic distances
Distances = (Atoms*(Atoms-1))/2;

% % Read number of timesteps. This must be inserted manually 
% % at the top of the excel file in sheet 1, square B1
Steps = xlsread(Filename, Sheets{1}, 'B1');
 
%The trajectory file kicked out my MK's code has 1 line for 
%each atom, and 2 lines for it talking to istelf i.e
Lines = Atoms+2;
Size = Lines*Steps-2;

% % Makes a copy of all the relevant data, and some rubbish data
% % from excel document (will need to expand for larger molecules)
Copy = xlsread(Filename, Sheets{1}, 'B3:D1000000');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculating Ra for each atomic distance
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% A 3-D matrix that holds all of the infromation form the 
% trajectory file. X-Atom no. Y-Atomic coords, Z-Step no.
Traj=zeros(Atoms,3,Steps);

%This set of loops reads from the copied data file and inserts
% all of the information in the 3-D matix Traj
for i=1:Atoms,          %For every atom
    for j=1:3,          %For every Coordinate
        for k=1:Steps,  %For every time-step
            Alpha=(k-1)*Lines+i; %Line used to iterate through each line in the excel file
            Traj(i,j,k)=Copy(Alpha,j);
        end
    end
end

% DispV, a 3-D array to hold information on the displacement 
% between atoms
DispV=zeros(Distances,5,Steps);

% This series of for loops determines the displacement vector 
% between  atoms for Disp V.
for k=1:Steps,
    whoop=1; %Whoop: a variable to iterate through the number of distances
    for i=1:Atoms,
        for j=1:Atoms,
            if j>i %Ensures that we only look at a pair once.
                DispV(whoop,1,k)=i;
                DispV(whoop,2,k)=j;
                DispV(whoop,3,k)=Traj(i,1,k)-Traj(j,1,k);
                DispV(whoop,4,k)=Traj(i,2,k)-Traj(j,2,k);
                DispV(whoop,5,k)=Traj(i,3,k)-Traj(j,3,k);
                                
                whoop=whoop+1;
            end
        end
    end
end

% DispS, A 3-D matrix that determine the scalar distances between 
% atoms from DispV.
DispS=zeros(Distances,3,Steps);
for k=1:Steps,
    whoop=1; %Whoop: a variable to iterate through the number of distances
    for i=1:Atoms,
        for j=1:Atoms,
            if j>i
                DispS(whoop,1,k)=i;
                DispS(whoop,2,k)=j;
                DispS(whoop,3,k)=sqrt(DispV(whoop,3,k)^2+DispV(whoop,4,k)^2+DispV(whoop,5,k)^2);
                whoop=whoop+1;
            end
        end
    end
end

% SumInvRa, a 2-D matrix used to calulate the sum of the inverted DispS
SumInvRa=zeros(Distances,3);
for k=1:Steps,
    whoop=1;
    for i=1:Atoms,
        for j=1:Atoms,
            if j>i
                SumInvRa(whoop,1)=i;
                SumInvRa(whoop,2)=j;
                SumInvRa(whoop,3)=SumInvRa(whoop,3)+(DispS(whoop,3,k))^(-1);
                whoop=whoop+1;
            end
        end
    end
end

% Ra, a 2-D matrix containing the calculated Ra of each atomic distance
Ra=zeros(Distances,3);
for k=1:Steps,
    whoop=1;
    for i=1:Atoms,
        for j=1:Atoms,
            if j>i
                Ra(whoop,1)=i;
                Ra(whoop,2)=j;
                Ra(whoop,3)=((1/Steps)*SumInvRa(whoop,3))^(-1);
                whoop=whoop+1;
            end
        end
    end
end
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Caclulating u, the amplitude of vibration
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% First need to calculate the average distance between each atom
% over all of the time-steps, AvR
AvR=zeros(Distances,3);

for k=1:Steps,
    whoop=1;
    for i=1:Atoms,
        for j=1:Atoms,
            if j>i
                AvR(whoop,1)=i;
                AvR(whoop,2)=j;
                AvR(whoop,3)=AvR(whoop,3)+(DispS(whoop,3,k));
                whoop=whoop+1;
            end
        end
    end
end
for l=1:Distances,
    AvR(l,3)=(1/Steps)*AvR(l,3);
end


% Calculating square of the difference between each r distance 
% and the average r for each time timestep
Sqdiff=zeros(Distances,3,Steps);
for k=1:Steps,
    whoop=1;
    for i=1:Atoms,
        for j=1:Atoms,
            if j>i
                Sqdiff(whoop,1,k)=i;
                Sqdiff(whoop,2,k)=j;
                Sqdiff(whoop,3,k)=((DispS(whoop,3,k))-AvR(whoop,3))^2;
                whoop=whoop+1;
            end
        end
    end
end



%Calculation of the amplitude of vibration
Amp=zeros(Distances,3);
for k=1:Steps,
    whoop=1;
    for i=1:Atoms,
        for j=1:Atoms,
            if j>i
                Amp(whoop,1)=i;
                Amp(whoop,2)=j;
                Amp(whoop,3)=Amp(whoop,3)+Sqdiff(whoop,3,k);
                whoop=whoop+1;
            end
        end
    end
end
for l=1:Distances,
    Amp(l,3)=(1/Steps)*Amp(l,3);
end

